@@ -7,7 +7,7 @@ from .save import get_save_client
 
 def check_s3():
     print("Checking S3 connection...")
-    get_save_client("s3")
+    get_save_client("S3")
 
 
 def check_db():
