@@ -93,7 +93,7 @@ class Collect:
         if self.sh.check_obj(cdclass, key):
             logger.info(f"Object {key} already exists")
             return True
-        for row in self.db.get_objects(key):
+        for row, length in self.db.get_objects(key):
             result = ObjResult(*row)
             if result.idcas and self.cas:
                 logger.info(
@@ -105,7 +105,11 @@ class Collect:
                 # )
             if result.obj:
                 self.sh.save_obj(
-                    io.BytesIO(result.obj).read(), cdclass, result.key, result.part
+                    io.BytesIO(result.obj).read(),
+                    cdclass,
+                    result.key,
+                    result.part,
+                    length,
                 )
             else:
                 logger.error(
