@@ -40,9 +40,10 @@ class Abstract_DB(ABC):
     def get_objects(self, key):
         sql = get_sql(settings.objs_sql).format(KEY=key)
         objects = list(self.select(sql))
-        if len(objects) > 0:
+        length = len(objects)
+        if length > 0:
             logger.info(f"Found {len(objects)} objects for key {key}")
         else:
             logger.error(f"Found zero objects for key {key}")
         for o in objects:
-            yield o
+            yield o, length
