@@ -8,6 +8,11 @@ from soft_collect.config import settings as s
 logger = logging.getLogger(__name__)
 
 
+def OutputTypeHandler(cursor, name, defaultType, size, precision, scale):
+    if defaultType == cx_Oracle.DB_TYPE_BLOB:
+        return cursor.var(cx_Oracle.DB_TYPE_LONG_RAW, arraysize=cursor.arraysize)
+
+
 class Oracle(Abstract_DB):
     def select(self, sql):
         with self.set_up_connection() as conn:
@@ -30,6 +35,7 @@ class Oracle(Abstract_DB):
                 encoding="UTF-8",
                 nencoding="UTF-8",
             )
+            connection.outputtypehandler = OutputTypeHandler
         except cx_Oracle.DatabaseError as e:
             logger.error(f"Can't set up a connection with {s.ip}/{s.base}, {e}")
             if _retry:
