@@ -12,7 +12,11 @@ class Postgres(Abstract_DB):
     def select(self, sql):
         with self.set_up_connection() as conn:
             c = conn.cursor()
-            yield from c.execute(sql)
+            c.execute(sql)
+            row = c.fetchone()
+            while row:
+                yield row
+                row = c.fetchone()
 
     def fetch_all(self, sql):
         with self.set_up_connection() as conn:
