@@ -1,4 +1,6 @@
+import io
 import logging
+import zipfile
 from abc import ABC
 from abc import abstractmethod
 
@@ -9,6 +11,14 @@ from soft_collect.config import settings
 logger = logging.getLogger(__name__)
 
 
+def check_format(obj):
+    buffer = io.BytesIO()
+    buffer.write(obj)
+    if zipfile.is_zipfile(buffer):
+        return "zip"
+    return "pdf"
+
+
 class AbstractSaveHandler(ABC):
     def __init__(self):
         s = settings
@@ -26,9 +36,9 @@ class AbstractSaveHandler(ABC):
     def get_file(self, filepath):
         pass
 
-    def save_obj(self, obj, cdclass, key, part):
-        pdf_dir = f"{self.dir}/{cdclass}/"  # TODO Check if pdf
-        filename = f"{key}_1/{part}.pdf"
+    def save_obj(self, obj, cdclass, key, part, length=1):
+        pdf_dir = f"{self.dir}/{cdclass}/"
+        filename = f"{key}_{length}/{part}.{check_format(obj)}"
         logger.info(f"Saving {filename}")
         self.write_file(pdf_dir, filename, obj)
 
